IMAP Tools
---
![IMAP Tools](https://BSDforge.COM/projects/mail/imaptools/imap_tools.jpg "IMAP Tools")

Welcome to the IMAP Tools!
--

    Author: Rick Sanders rfs9999@earthlink.net
    Maintainer: Chris Hutchinson codeberg AT bsdforge.com

What is the [IMAP](#what-is-in-the-imap-tools-set) Tools Set?

It is a set of [Perl](https://www.perl.org/about.html) programs to
manage [IMAP](https://en.wikipedia.org/wiki/IMAP) services.
IMAP Tools allowd you to do a great many things, including the following:

* Copy a user's folders and messages to a new server ([imapcopy.pl](https://bsdforge.com/projects/mail/imaptools/details#imapcopy))
* Bulk migration of hundreds or thousands of users to a new hosting server ([migrateIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#migrateIMAP))
* Move messages between folders based on a set of rules ([imapfilter.pl](https://bsdforge.com/projects/mail/imaptools/details#imapfilter))
* Back up and restore IMAP accounts ([imapdump.pl](https://bsdforge.com/projects/mail/imaptools/details#imapdump) and 
[dumptoIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#dumptoIMAP))
* Synchronize accounts on two different IMAP servers ([imapsync.pl](https://bsdforge.com/projects/mail/imaptools/details#imapsync))
* Purge duplicate messages ([delIMAPdups.pl](https://bsdforge.com/projects/mail/imaptools/details#delIMAPdups))
* Load messages from Maildir servers into IMAP and vice-versa ([maildir_to_imap.pl](https://bsdforge.com/projects/mail/imaptools/details#maildir_to_imap) and
[imap_to_maildir.pl](https://bsdforge.com/projects/mail/imaptools/details#imap_to_maildir))
* Load messages from Mbox servers into IMAP and vice-versa ([IMAPtoMbox.pl](https://bsdforge.com/projects/mail/imaptools/details#IMAPtoMbox) and
[MboxtoIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#MboxtoIMAP))
* and a lot of other things

* [What is in the IMAP Tools Set?](#what-is-in-the-imap-tools-set)
* [IMAP Tools User Guide](https://bsdforge.com/projects/mail/imaptools/IMAP_Tools_User_Guide.pdf)
* [IMAP Tools FAQ](https://bsdforge.com/projects/mail/imaptools/faq)
* [Examples](https://bsdforge.com/projects/mail/imaptools/examples)


**SSL Support**
: Most of the IMAP Tools utilities support SSL. SSL support is implemented using
[OpenSSL](https://www.openssl.org/) and the
[IO::Socket::SSL](http://search.cpan.org/search?query=io%3A%3Asocket%3A%3Assl)
[Perl](https://perl.org) module. Both must be installed on the system where you are
running these tools.

**OAUTH2 Support**
: OAUTH2 enables an application to access a user's account without having to use a
password. This is considered to be more secure than any method in which the user
supplies his password. Google's policy is that all other access methods are
"less secure" and they now require a user to enable "less secure" methods in their
account settings or a password-based login will be disallowed.
: Support for OAUTH2 logins was added to the IMAP Tools added support in version
1.300 which was released on 10/17/2014.
: Please see [OAUTH (Wikipedia)](https://en.wikipedia.org/wiki/OAuth) and
[OAUTH2 (Gmail)](https://developers.google.com/gmail/xoauth2_protocol) for more
information.
: [OAUTH2 Logins](https://developers.google.com/accounts/docs/OAuth2Login) explains
how to create a project in Gmail, register it, and create client credentials to make
use of tokens for accessing Gmail accounts. As explained in that article a user must
grant permission to the application before it can use tokens to access the user's
account. Tokens are good only for a short period of time, typically one hour, but
an application can issue a "refresh" command and get a fresh copy of the token.
: **Using OAUTH2 tokens with IMAP Tools**
To use an OAUTH2 token with the IMAP Tools simply specify the token in place 
of the password with the prefix "oauth2:" which will tell the tool that it
is a OAUTH2 token rather than a password.
: For example, let's say that you have obtained a  token ---
`ya29.oQDDSxPm3ciwisd1cw3Mxb32WyoMUsbxa5l5TYfqjooMb7cPNtX6Chbl` --- and you are
going to use it with imapcopy:
: `imapcopy.pl -S imap.gmail.com:993/username/oauth2:ya29.oQDDSxPm3ciwisd1cw3Mxb32WyoMUsbxa5l5TYfqjooMb7cPNtX6Chbl`
: That's all there is to using OAUTH2 with the IMAP Tools!

**CRAM-MD5 Logins**
: Many of the tools support the CRAM-MD5 login method. To invoke a CRAM-MD5 login 
append <font color="red"><b>/CRAM-MD5</b></font> after the host/username/password
string. For example:
: `-S host/john/welcome/CRAM-MD5`

IMAP debugging and tracing
: Some tips on debugging problems using the IMAP Tools.
: Connection problems.
: The first step in diagnosing failure to connect is to confirm that you have basic
network connectivity to the host.  First try to ping the server.  If that works then
telnet to the IMAP port with the following command:
: `telnet server 143`
: If you do not get a response then it is likely that there is a firewall blocking
access to port 143 on the server.
: **Turning on Debug mode in IMAP Tools**
: The IMAP tools will provide a wealth of information when you are trying to figure
out a problem if you enable debug mode with the -d and -I arguments. When -I is set
the IMAP tools will record in the logfile all IMAP commands sent to the server and
the responses the servers back.
: That information can be extremely important in diagnosing and resolving issues so
it is always a good idea to turn debug on when you are experiencing problems. The
IMAP Tools developer will usually request it when you are working with him on a
problem.
: It's hard to believe but he actually likes looking at that messy IMAP protocol
stuff.

What is in the IMAP Tools Set? {#what-is-in-the-imap-tools-set}
--

1. [imapcopy.pl](https://bsdforge.com/projects/mail/imaptools/details#imapcopy)
2. [pop3toimap.pl](https://bsdforge.com/projects/mail/imaptools/details#pop3toimap)
3. [migrateIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#migrateIMAP)
4. [imapsync.pl](https://bsdforge.com/projects/mail/imaptools/details#imapsync)
5. [imapfilter.pl](https://bsdforge.com/projects/mail/imaptools/details#imapfilter)
6. [imapdump.pl](https://bsdforge.com/projects/mail/imaptools/details#imapdump)
7. [dumptoIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#dumptoIMAP)
8. [IMAPtoMbox.pl](https://bsdforge.com/projects/mail/imaptools/details#IMAPtoMbox)
9. [MboxtoIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#MboxtoIMAP)
10. [maildir_to_imap.pl](https://bsdforge.com/projects/mail/imaptools/details#maildir_to_imap)
11. [imap_to_maildir.pl](https://bsdforge.com/projects/mail/imaptools/details#imap_to_maildir)
12. [delIMAPdups.pl](https://bsdforge.com/projects/mail/imaptools/details#delIMAPdups)
13. [delete_imap_mailboxes.pl](https://bsdforge.com/projects/mail/imaptools/details#delete_imap_mailboxes)
14. [mozillatoIMAP.pl](https://bsdforge.com/projects/mail/imaptools/details#thunderbird_to_imap)
15. [imapCapability.pl](https://bsdforge.com/projects/mail/imaptools/details#imapCapability)
16. [imapPing.pl](https://bsdforge.com/projects/mail/imaptools/details#imapPing)
17. [purgeMbx.pl](https://bsdforge.com/projects/mail/imaptools/details#purgeMbx)
18. [trash.pl](https://bsdforge.com/projects/mail/imaptools/details#trash)
19. [imap_audit.pl](https://bsdforge.com/projects/mail/imaptools/details#imap_audit)
20. [list_imap_folders.pl](https://bsdforge.com/projects/mail/imaptools/details#list_imap_folders)
21. [list_account_sizes](https://bsdforge.com/projects/mail/imaptools/details#list_account_sizes)
22. [imap_search.pl](https://bsdforge.com/projects/mail/imaptools/details#imap_search.pl)
